==> goal-emohawk-environment-3.3.1-20120925.030410-59-sources.jar: nl/tudelft/goal/emohawk/environment/EmohawkEnvironment.java <==
/**
 * Emohawk Bot, an implementation of the environment interface standard that 
 * facilitates the connection between GOAL and Emohawk. 
 * 
 * Copyright (C) 2012 Emohawk Bot authors.
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses/>.
 */

package nl.tudelft.goal.emohawk.environment;

import java.util.HashMap;

import cz.cuni.amis.pogamut.ut2004.bot.impl.UT2004BotController;

import nl.tudelft.goal.EIS2Java.handlers.ActionHandler;
import nl.tudelft.goal.EIS2Java.handlers.AsynchronousEntity;
import nl.tudelft.goal.EIS2Java.handlers.PerceptHandler;
import nl.tudelft.goal.EIS2Java.handlers.SynchronizedActionHandler;
import nl.tudelft.goal.EIS2Java.handlers.SynchronizedPerceptHandler;
import nl.tudelft.goal.EIS2Java.translation.Translator;
import nl.tudelft.goal.emohawk.agent.EmohawkBotBehavior;
import nl.tudelft.goal.emohawk.translators.AgentInfoTranslator;
import nl.tudelft.goal.emohawk.translators.AnimTypeTranslator;
import nl.tudelft.goal.emohawk.translators.EmoticonTypeTranslator;
import nl.tudelft.goal.emohawk.translators.GameTranslator;
import nl.tudelft.goal.emohawk.translators.PlaceTranslator;
import nl.tudelft.goal.emohawk.translators.PlayerTranslator;
import nl.tudelft.goal.emohawk.translators.UnrealIdOrLocationTranslator;
import nl.tudelft.goal.unreal.environment.AbstractUnrealEnvironment;
import nl.tudelft.goal.unreal.translators.LocationTranslator;
import nl.tudelft.goal.unreal.translators.NavPointTranslator;
import nl.tudelft.goal.unreal.translators.RotationTranslator;
import nl.tudelft.goal.unreal.translators.TeamTranslator;
import nl.tudelft.goal.unreal.translators.UnrealIdTranslator;
import nl.tudelft.goal.unreal.translators.VelocityTranslator;
import eis.exceptions.EntityException;
import eis.exceptions.ManagementException;
import eis.iilang.Identifier;
import eis.iilang.Parameter;
import eis.iilang.ParameterList;

public class EmohawkEnvironment extends AbstractUnrealEnvironment {

	/**
	 * Generated serialVersionUID.
	 */
	private static final long serialVersionUID = 8240549393243585632L;

	@Override
	protected void registerTranslators() {

		Translator translator = Translator.getInstance();

		/*
		 * Translators provided by the BaseUnrealEnvironment.
		 * 
		 * Please list these in lexical order.
		 */

		LocationTranslator locationTranslator = new LocationTranslator();
		translator.registerJava2ParameterTranslator(locationTranslator);
		translator.registerParameter2JavaTranslator(locationTranslator);

		/*
		 * To translate from Parameter2Java we are given an UnrealId. However we
		 * can not access the agents memory during translation. To work around
		 * this we store everything we have send to any agent. Hence the same
		 * object has to be used for both directions.
		 */
		NavPointTranslator navPointTranslator = new NavPointTranslator();
		translator.registerJava2ParameterTranslator(navPointTranslator);
		translator.registerParameter2JavaTranslator(navPointTranslator);

		RotationTranslator rotationTranslator = new RotationTranslator();
		translator.registerJava2ParameterTranslator(rotationTranslator);
		translator.registerParameter2JavaTranslator(rotationTranslator);

		TeamTranslator teamTranslator = new TeamTranslator();
		translator.registerJava2ParameterTranslator(teamTranslator);
		translator.registerParameter2JavaTranslator(teamTranslator);

		UnrealIdTranslator unrealIdTranslator = new UnrealIdTranslator();
		translator.registerJava2ParameterTranslator(unrealIdTranslator);
		translator.registerParameter2JavaTranslator(unrealIdTranslator);

		VelocityTranslator velocityTranslator = new VelocityTranslator();
		translator.registerJava2ParameterTranslator(velocityTranslator);
		translator.registerParameter2JavaTranslator(velocityTranslator);

		/*
		 * Translators provided by the EmohawkBot environment.
		 * 
		 * Please list these in lexical order.
		 */
		AgentInfoTranslator agentInfoTranslator = new AgentInfoTranslator();
		translator.registerJava2ParameterTranslator(agentInfoTranslator);

		AnimTypeTranslator animTypeTranslator = new AnimTypeTranslator();
		translator.registerJava2ParameterTranslator(animTypeTranslator);
		translator.registerParameter2JavaTranslator(animTypeTranslator);

		EmoticonTypeTranslator emoticonTypeTranslator = new EmoticonTypeTranslator();
		translator.registerJava2ParameterTranslator(emoticonTypeTranslator);
		translator.registerParameter2JavaTranslator(emoticonTypeTranslator);

		GameTranslator gameTranslator = new GameTranslator();
		translator.registerJava2ParameterTranslator(gameTranslator);
		
		PlaceTranslator placeTranslator = new PlaceTranslator();
		translator.registerJava2ParameterTranslator(placeTranslator);
		
		PlayerTranslator playerTranslator = new PlayerTranslator();
		translator.registerJava2ParameterTranslator(playerTranslator);
		
		UnrealIdOrLocationTranslator unrealIdOrLocationTranslator = new UnrealIdOrLocationTranslator();
		translator.registerParameter2JavaTranslator(unrealIdOrLocationTranslator);

	}

	public static void main(String[] args) throws ManagementException {
		HashMap<String, Parameter> map = new HashMap<String, Parameter>();
		map.put("botNames", new ParameterList(new Identifier("Test")));
		new EmohawkEnvironment().init(map);

	}

	@Override
	protected Class<EmohawkBotBehavior> getControlerClass() {
		return EmohawkBotBehavior.class;
	}

	@Override
	protected PerceptHandler createPerceptHandler(UT2004BotController controller) throws EntityException {
		return new SynchronizedPerceptHandler((AsynchronousEntity) controller);
	}

	@Override
	protected ActionHandler createActionHandler(UT2004BotController controller) throws EntityException {
		return new SynchronizedActionHandler((AsynchronousEntity) controller);
	}

}

==> goal-emohawk-environment-3.3.2-20121023.030805-29-sources.jar: nl/tudelft/goal/emohawk/environment/EmohawkEnvironment.java <==
/**
 * Emohawk Bot, an implementation of the environment interface standard that 
 * facilitates the connection between GOAL and Emohawk. 
 * 
 * Copyright (C) 2012 Emohawk Bot authors.
 * 
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <http://www.gnu.org/licenses/>.
 */

package nl.tudelft.goal.emohawk.environment;

import java.util.HashMap;

import cz.cuni.amis.pogamut.ut2004.bot.impl.UT2004BotController;

import nl.tudelft.goal.EIS2Java.handlers.ActionHandler;
import nl.tudelft.goal.EIS2Java.handlers.AsynchronousEntity;
import nl.tudelft.goal.EIS2Java.handlers.PerceptHandler;
import nl.tudelft.goal.EIS2Java.handlers.SynchronizedActionHandler;
import nl.tudelft.goal.EIS2Java.handlers.SynchronizedPerceptHandler;
import nl.tudelft.goal.EIS2Java.translation.Translator;
import nl.tudelft.goal.emohawk.agent.EmohawkBotBehavior;
import nl.tudelft.goal.emohawk.translators.AgentInfoTranslator;
import nl.tudelft.goal.emohawk.translators.AnimTypeTranslator;
import nl.tudelft.goal.emohawk.translators.EmoticonTypeTranslator;
import nl.tudelft.goal.emohawk.translators.GameTranslator;
import nl.tudelft.goal.emohawk.translators.NavPointTranslator;
import nl.tudelft.goal.emohawk.translators.PlaceTranslator;
import nl.tudelft.goal.emohawk.translators.PlayerTranslator;
import nl.tudelft.goal.emohawk.translators.UnrealIdOrLocationTranslator;
import nl.tudelft.goal.unreal.environment.AbstractUnrealEnvironment;
import nl.tudelft.goal.unreal.translators.LocationTranslator;
import nl.tudelft.goal.unreal.translators.RotationTranslator;
import nl.tudelft.goal.unreal.translators.TeamTranslator;
import nl.tudelft.goal.unreal.translators.UnrealIdTranslator;
import nl.tudelft.goal.unreal.translators.VelocityTranslator;
import eis.exceptions.EntityException;
import eis.exceptions.ManagementException;
import eis.iilang.Identifier;
import eis.iilang.Parameter;
import eis.iilang.ParameterList;

public class EmohawkEnvironment extends AbstractUnrealEnvironment {

	/**
	 * Generated serialVersionUID.
	 */
	private static final long serialVersionUID = 8240549393243585632L;

	@Override
	protected void registerTranslators() {

		Translator translator = Translator.getInstance();

		/*
		 * Translators provided by the BaseUnrealEnvironment.
		 * 
		 * Please list these in lexical order.
		 */

		LocationTranslator locationTranslator = new LocationTranslator();
		translator.registerJava2ParameterTranslator(locationTranslator);
		translator.registerParameter2JavaTranslator(locationTranslator);

		/*
		 * To translate from Parameter2Java we are given an UnrealId. However we
		 * can not access the agents memory during translation. To work around
		 * this we store everything we have send to any agent. Hence the same
		 * object has to be used for both directions.
		 */
		NavPointTranslator navPointTranslator = new NavPointTranslator();
		translator.registerJava2ParameterTranslator(navPointTranslator);
		translator.registerParameter2JavaTranslator(navPointTranslator);

		RotationTranslator rotationTranslator = new RotationTranslator();
		translator.registerJava2ParameterTranslator(rotationTranslator);
		translator.registerParameter2JavaTranslator(rotationTranslator);

		TeamTranslator teamTranslator = new TeamTranslator();
		translator.registerJava2ParameterTranslator(teamTranslator);
		translator.registerParameter2JavaTranslator(teamTranslator);

		UnrealIdTranslator unrealIdTranslator = new UnrealIdTranslator();
		translator.registerJava2ParameterTranslator(unrealIdTranslator);
		translator.registerParameter2JavaTranslator(unrealIdTranslator);

		VelocityTranslator velocityTranslator = new VelocityTranslator();
		translator.registerJava2ParameterTranslator(velocityTranslator);
		translator.registerParameter2JavaTranslator(velocityTranslator);

		/*
		 * Translators provided by the EmohawkBot environment.
		 * 
		 * Please list these in lexical order.
		 */
		AgentInfoTranslator agentInfoTranslator = new AgentInfoTranslator();
		translator.registerJava2ParameterTranslator(agentInfoTranslator);

		AnimTypeTranslator animTypeTranslator = new AnimTypeTranslator();
		translator.registerJava2ParameterTranslator(animTypeTranslator);
		translator.registerParameter2JavaTranslator(animTypeTranslator);

		EmoticonTypeTranslator emoticonTypeTranslator = new EmoticonTypeTranslator();
		translator.registerJava2ParameterTranslator(emoticonTypeTranslator);
		translator.registerParameter2JavaTranslator(emoticonTypeTranslator);

		GameTranslator gameTranslator = new GameTranslator();
		translator.registerJava2ParameterTranslator(gameTranslator);
		
		PlaceTranslator placeTranslator = new PlaceTranslator();
		translator.registerJava2ParameterTranslator(placeTranslator);
		
		PlayerTranslator playerTranslator = new PlayerTranslator();
		translator.registerJava2ParameterTranslator(playerTranslator);
		
		UnrealIdOrLocationTranslator unrealIdOrLocationTranslator = new UnrealIdOrLocationTranslator();
		translator.registerParameter2JavaTranslator(unrealIdOrLocationTranslator);

	}

	public static void main(String[] args) throws ManagementException {
		HashMap<String, Parameter> map = new HashMap<String, Parameter>();
		map.put("botNames", new ParameterList(new Identifier("Test")));
		new EmohawkEnvironment().init(map);

	}

	@Override
	protected Class<EmohawkBotBehavior> getControlerClass() {
		return EmohawkBotBehavior.class;
	}

	@Override
	protected PerceptHandler createPerceptHandler(UT2004BotController controller) throws EntityException {
		return new SynchronizedPerceptHandler((AsynchronousEntity) controller);
	}

	@Override
	protected ActionHandler createActionHandler(UT2004BotController controller) throws EntityException {
		return new SynchronizedActionHandler((AsynchronousEntity) controller);
	}

}
